{% load wagtailcore_tags %}<!doctype html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.0.0-beta2/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-BmbxuPwQa2lc/FVzBcNJ7UAyJxM6wuqIj61tLrc4wSX0szH/Ev+nYRRuWlolflfl" crossorigin="anonymous">

    <title>{{ page.title }}</title>
  </head>
  <body>
    <div class="container">
      <h1 class="mt-2">{{ page.title }}</h1>
      {% for block in page.body %}
        {% include_block block %}
      {% endfor %}
    </div>
  </body>
</html>
