# Generated by Django 2.2.19 on 2021-03-04 17:12

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.documents.blocks
import wagtail.images.blocks
import wagtail_cblocks.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0059_apply_collection_ordering'),
    ]

    operations = [
        migrations.CreateModel(
            name='StandardPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('body', wagtail.core.fields.StreamField([('title_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(form_classname='title', label='Title')), ('level', wagtail.core.blocks.ChoiceBlock(choices=[(2, 'Level 2 heading'), (3, 'Level 3 heading'), (4, 'Level 4 heading'), (5, 'Level 5 heading')], label='Level'))])), ('paragraph_block', wagtail_cblocks.blocks.ParagraphBlock()), ('button_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(label='Text')), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], form_classname='link-block__target', icon='link', max_num=1))]))])), ('image_block', wagtail.core.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('caption', wagtail.core.blocks.CharBlock(label='Caption', required=False)), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], form_classname='link-block__target', icon='link', max_num=1))], required=False))]))])),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
    ]
